@@ -363,12 +363,7 @@ end
     @inferred rfft(x)
 
     if ndims(x) == 2
-        if VERSION >= v"1.6.7"
-            @inferred brfft(x,18)
-        else
-            # See Julia issue #23063
-            @test_broken @inferred brfft(x,18)
-        end
+        @inferred brfft(x,18)
     end
 
     @inferred brfft(y,10)
@@ -382,21 +377,6 @@ end
     end
     for f in (plan_bfft, plan_fft, plan_ifft,
               plan_rfft, fft, bfft, fft_, ifft)
-        # More of #23063 (why does plan_rfft work and the others don't)?
-        if ndims(x) == 2 && f != plan_rfft
-            if VERSION >= v"1.6.7"
-                @inferred f(x)
-                if isa(f, Plan)
-                    @inferred plan_inv(f(x))
-                end
-            else
-                @test_broken @inferred f(x)
-                if isa(f, Plan)
-                    @test_broken @inferred plan_inv(f(x))
-                end
-                continue
-            end
-        end
         p = @inferred f(x)
         if isa(p, Plan)
             @inferred plan_inv(p)
@@ -528,7 +508,7 @@ end # fftw_provider == "fftw"
     end
 
     # check whether FFTW on this architecture has nontrivial alignment requirements
-    nontrivial_alignment = FFTW.fftw_provider == "fftw" && ccall((:fftwf_alignment_of, FFTW.libfftw3f()), Int32, (Int,), 8) != 0
+    nontrivial_alignment = FFTW.fftw_provider == "fftw" && ccall((:fftwf_alignment_of, FFTW.libfftw3f), Int32, (Int,), 8) != 0
     if nontrivial_alignment
         @test_throws ArgumentError plan_rfft(Array{Float32}(undef, 32)) * view(A, 2:33)
         @test_throws ArgumentError plan_fft(Array{Complex{Float32}}(undef, 32)) * view(Ac, 2:33)
